@@ -1,6 +1,6 @@
 # Responses
-RESPONSE_OK = b"1"
-RESPONSE_ERROR = b"0"
+RESPONSE_OK = "1"
+RESPONSE_ERROR = "0"
 
 # Statuses
 STATUS_DISCONNECTED = "Disconnected"
