@@ -33,11 +33,11 @@ class Device(Subject, YamlSerializable):
     Connection error handling:
         : if connect() => error state
            : disconnect() if critical error
-           : cloe(), reconnect() if not critical error
+           : close(), reconnect() if not critical error
         : if connect() => connection timeout
-            : handle_connection_error(), close(), reconnect()
+            : handle_connection_error(), close()
         : if Device.connected and response timeout()
-            : handle_response_error(), close_connection(), reconnect()
+            : handle_response_error(), close_connection()
 
     Disconnection is done in sequence:
         : disconnect()
@@ -48,7 +48,6 @@ class Device(Subject, YamlSerializable):
     id_generator = device_id_generator()
     connection_timeout = 4000
     response_timeout = 4000
-    allow_reconnect = True
     session = None
     max_command_retry = 0
     command_retry_count = 0
@@ -183,7 +182,10 @@ class Device(Subject, YamlSerializable):
             self.attributes[group][name] = attribute
 
         attribute_exists = attribute.attribute_id in self.attributes_sharing_map
-        self.attributes_sharing_map[attribute.attribute_id] = attribute_list
+        if attribute_exists:
+            self.attributes_sharing_map[attribute.attribute_id].append(attribute_list)
+        else:
+            self.attributes_sharing_map[attribute.attribute_id] = [attribute_list]
         if attribute_exists and kamzik3.session.publisher is not None:
             header = "{}.{}".format(attribute.attribute_id, TOKEN_ATTRIBUTE_REPLACE)
             kamzik3.session.publisher.push_message(header, attribute)
@@ -274,17 +276,6 @@ class Device(Subject, YamlSerializable):
         self.session = session
         session.add_device(self)
 
-    def reconnect_allowed(self):
-        """
-        Allow device to reconnect or not.
-        :return: Bool
-        """
-        if self.connecting or self.connected:
-            self.close()
-            return True
-        else:
-            return self.allow_reconnect
-
     def attach_attribute_callback(self, attribute, callback, max_update_rate=None, key_filter=None):
         """
         Attach callback for every change of attribute.
@@ -503,7 +494,7 @@ class Device(Subject, YamlSerializable):
         except DeviceError:
             """
             Here we encountered connection error.
-            Log error and wait for reconnection.
+            Log error.
             """
             self.logger.exception(u"Error during connection")
 
@@ -639,12 +630,9 @@ class Device(Subject, YamlSerializable):
         If Device was reconnect return True, False otherwise.
         :return: bool
         """
-        if self.reconnect_allowed():
-            mapping = self.yaml_mapping()
-            self.__init__(**mapping)
-            return True
-        else:
-            return False
+        mapping = self.yaml_mapping()
+        self.__init__(**mapping)
+        return True
 
     def set_status(self, status):
         """
@@ -883,7 +871,7 @@ class Device(Subject, YamlSerializable):
                                             "exposed_parameters") and method.__name__ not in self.exposed_methods:
                 self.exposed_methods.append((method.__name__, method.exposed_parameters))
 
-    def wait_for_status(self, statuses, retry_timeout=1000, callback=None):
+    def wait_for_status(self, statuses, retry_timeout=1000, throw_exception=True, callback=None):
         """
         Wait until device change it's status in one defined in statuses.
         If callback is set, then method is executed in non blocking thread.
@@ -894,30 +882,35 @@ class Device(Subject, YamlSerializable):
         """
 
         def _wait(_callback=None):
-            success = True
+            success = self.in_statuses(statuses)
             retry_counter = 0
-            while not self.in_statuses(statuses):
+            while not success:
                 if not self.connected:
-                    return False
+                    break
                 time.sleep(0.05)
+                retry_counter += 50
+                success = self.in_statuses(statuses)
                 if retry_counter >= retry_timeout:
                     break
-                retry_counter += 50
             if _callback is not None:
                 _callback(success)
-            else:
+            elif throw_exception:
                 if not success:
                     raise DeviceError(
                         "Status was not set to {} within timeout of {} ms".format(statuses, retry_timeout))
                 else:
                     return True
+            else:
+                return success
 
         if callback is None:
             return _wait()
         else:
-            Thread(target=_wait, args=[callback]).start()
+            thread = Thread(target=_wait, args=[callback])
+            thread.start()
+            return thread
 
-    def wait_until_value_set(self, attribute, value, retry_timeout=1000, callback=None):
+    def wait_until_value_set(self, attribute, value, retry_timeout=1000, throw_exception=True, callback=None):
         """
         This function triggers callback or block until attribute is set to requested value.
         There is retry_timeout of 1s until DeviceError is raised.
@@ -930,24 +923,26 @@ class Device(Subject, YamlSerializable):
 
         def _wait(_callback=None):
             attribute_object = self.get_attribute(attribute)
-            success = True
+            success = attribute_object[VALUE] == value
             retry_counter = 0
-            while attribute_object[VALUE] != value:
+            while not success:
                 if not self.connected:
-                    return False
-                time.sleep(0.05)
-                if retry_counter >= retry_timeout:
-                    success = False
                     break
+                time.sleep(0.05)
                 retry_counter += 50
+                success = attribute_object[VALUE] == value
+                if retry_counter >= retry_timeout:
+                    break
             if _callback is not None:
                 _callback(success)
-            else:
+            elif throw_exception:
                 if not success:
                     raise DeviceError(
                         "Value of {} was not set to {} within timeout of {} ms".format(attribute, value, retry_timeout))
                 else:
                     return True
+            else:
+                return success
 
         if callback is None:
             return _wait()
