@@ -219,9 +219,15 @@ class DeviceLexium(DeviceSocket):
                 out = re.search("IS = ([0-9]), ([0-9]), ([0-9])", line)
                 if out:
                     if out.group(1) == "3":
-                        self.notify((0, ATTR_USE_POSITIVE_LIMIT_SWITCH), bool(int(out.group(3))))
+                        if int(out.group(2)) == 0:
+                            self.notify((0, ATTR_USE_POSITIVE_LIMIT_SWITCH), False)
+                        else:
+                            self.notify((0, ATTR_USE_POSITIVE_LIMIT_SWITCH), bool(int(out.group(3))))
                     elif out.group(1) == "4":
-                        self.notify((0, ATTR_USE_NEGATIVE_LIMIT_SWITCH), bool(int(out.group(3))))
+                        if int(out.group(2)) == 0:
+                            self.notify((0, ATTR_USE_POSITIVE_LIMIT_SWITCH), False)
+                        else:
+                            self.notify((0, ATTR_USE_NEGATIVE_LIMIT_SWITCH), bool(int(out.group(3))))
                         break
 
     def start_polling(self):
