@@ -15,7 +15,8 @@ from kamzik3.devices.attributeLogger import AttributeLogger, ATTR_LOGGING
 from kamzik3.devices.device import Device
 from kamzik3.devices.deviceClient import DeviceClient
 from kamzik3.devices.general.measurementGroup import MeasurementGroup
-from kamzik3.snippets.snippetLogging import set_rotating_file_handler, set_sys_exception_handler, get_console_handler
+from kamzik3.snippets.snippetLogging import set_rotating_file_handler, set_sys_exception_handler, get_console_handler, \
+    set_rocket_chat_handler
 from kamzik3.snippets.snippetsControlLoops import control_asyncore_loop, control_device_poller, control_port_read_loop, \
     control_device_connection_poller
 from kamzik3.snippets.snippetsDecorators import expose_method
@@ -244,6 +245,7 @@ class DeviceSession(Device):
         logger = logging.getLogger(u"Console")
         set_rotating_file_handler(logger, os.path.join(log_directory, self.LOG_CONSOLE_OUTPUT_FILE))
         set_sys_exception_handler(logger)
+        # set_rocket_chat_handler(logger, level=logging.ERROR)
         logger.setLevel(self.log_level)
         logger.addHandler(handler)
 
@@ -260,6 +262,7 @@ class DeviceSession(Device):
 
         handler = get_console_handler()
         logger = logging.getLogger(u"Gui")
+        # set_rocket_chat_handler(logger, level=logging.ERROR)
         set_rotating_file_handler(logger, os.path.join(log_directory, self.LOG_GUI_OUTPUT_FILE))
         logger.setLevel(logging.DEBUG)
         logger.addHandler(handler)
@@ -295,6 +298,7 @@ class DeviceSession(Device):
         handler = get_console_handler()
         logger = logging.getLogger(u"Device")
         set_rotating_file_handler(logger, os.path.join(log_directory, self.LOG_DEVICE_OUTPUT_FILE))
+        # set_rocket_chat_handler(logger, level=logging.ERROR)
         logger.setLevel(self.log_level)
         logger.addHandler(handler)
 
@@ -312,6 +316,7 @@ class DeviceSession(Device):
         handler = get_console_handler()
         logger = logging.getLogger(u"Macro")
         set_rotating_file_handler(logger, os.path.join(log_directory, self.LOG_MACRO_OUTPUT_FILE))
+        # set_rocket_chat_handler(logger, level=logging.MACRO_STATE)
         logger.setLevel(logging.DEBUG)
         logger.addHandler(handler)
 
