@@ -127,6 +127,7 @@ class Macro(Common, Device):
         if self.get_state() == BUSY:
             raise DeviceError(u"Macro is already running")
         self.resolve_scans()
+        self.logger.log(logging.MACRO_STATE, "{} started\n```{}```".format(self.device_id, self.macro_logger.preset_header))
         super(Macro, self).start()
         if self.macro_logger is not None:
             self.macro_logger.start()
@@ -242,6 +243,7 @@ class Macro(Common, Device):
             self.error(e)
             raise e
         finally:
+            self.logger.log(logging.MACRO_STATE, "{} done".format(self.device_id))
             if callable(callback):
                 callback()
 
@@ -251,6 +253,7 @@ class Macro(Common, Device):
             raise DeviceError(u"Macro is not running")
 
         self.before_macro_stops()
+        self.logger.log(logging.MACRO_STATE, "{} stopped".format(self.device_id))
         super(Macro, self).stop()
 
         for link in self.chain + self.branch:
