@@ -44,7 +44,8 @@ def get_attribute_unit_range(attribute):
 
     try:
         min_unit = scale * 10 ** -attribute[DECIMALS]
-        max_unit = scale * abs(attribute[MAX])
+        abs_min, abs_max = abs(attribute[MIN]), abs(attribute[MAX])
+        max_unit = scale * (abs_max if abs_max > abs_min else abs_min)
     except TypeError:
         raise TypeError
 
